---
layout: default
title: 10. Balsa Gliders Facilitator Guide
nav_order: 25
mathjax: true
---


# Faciltator Guide: Balsa Gliders
By Claire Dorsett

## Table of contents
{: .no_toc .text-delta }

- TOC
{:toc}


## Overview
In this multi-step activity appropriate for all ability levels, learners will design, fabricate, and test a three-piece glider.

This lesson introduce seach of the three machines on the micro lab cart: learners will laser cut a fuselage, vinyl cut cardstock wings and tail, and 3D print clip-on weights.

They can then test how fast, far, and straight their assembled gliders fly. If time allows, they can iterate on their designs.

In addition to the three machines, this activity offers a high-level introduction to CAD and parametric modeling.

### Context
Four forces act upon a plane in the air: thrust, lift, gravity, and drag.

  1. **Thrust**: the force propelling a plane forward. Thrust is most often generated by fuel combustion (or your throw!).
  2. **Lift**: the force acting upward on a plane’s wings to keep it aloft. Lift is generated as a plane moves forward and air moves more quickly across the top of its wings than beneath them. Generally, the larger the wings, the greater the lift.
  3. **Gravity**: the force pulling a plane’s mass down toward the ground. Lighter materials can help a plane stay airborne longer.
  4. **Drag**: the frictional force a plane experiences from air flowing past it. Drag is the opposite of thrust, and slows a plane down. It is largely influenced by its tail design.

Planes’ designs must balance all of these forces. The shapes, sizes, and materials used for the wings, body, nose, and tail can all drastically affect the way a plane flies. How can we engineer a glider to take advantage of these forces?

#### In the Real World:
Engineers don’t create perfect designs on the first try.

They test, redesign, and retest their ideas again and again, making small changes each time based on their observations. This is called iterative prototyping, and it’s a key part of the engineering design process. Instead of thinking of lackluster designs as “failures,” think of them as rough drafts of a finished product. Each one is a step closer to success.

#### Parametric Design
Parametric design is a smart way to tweak digital designs.

Instead of creating a new CAD model from scratch each time they need to make a change, engineers use something called parametric modeling. This means they assign adjustable variables to each dimension of their design instead of values.

These labels can be single variables, like x  in a math equation, or they can be a function of a variable, like x+6 or x/2. We could even make them a function of each other: wing width  could equal body length - tail width.  

Parametric design allows engineers to scale an entire model up or down or make small tweaks to a single part.

{:toc}

## Scalability
### 1. Exposure: Manipulating Parametric Designs
Customize the shape of a pre-templated fuselage, wings, and tail by adjusting sliders, clicking and dragging handles on spines, or entering values into parametric text boxes.

- Light lift: exposes learners to CAD and allows for customization without requiring them to do any design themselves, freeing up time for fabrication and iterative experimentation.
- Introduces the concept and applications of parametric design.
- Uses pre-printed clip-on weights.
- **Curricular tie-ins**: engineering, aerodynamics


### 2. Exploration: Designing around Templated Features
Connect the dots around pre-designed parametric assembly slots to draw customized shapes for a glider's fuselage, wings, and tail.

- Allows for greater customization without designing from scratch.
- Uses pre-printed clip-on weights, or allows for design of custom weights.
- **Curricular tie-ins**: engineering, aerodynamics


### 3. Deep Dive: Open-Ended Design Challenge
Use CAD software to design the parts of a glider from scratch, within the constraints of a templated bounding box.

- Introduces more complex spatial reasoning and design in three dimensions.
- Open-ended customization.
- Recommended for multi-session instruction, including teaching caliper use, press-fit assembly, and design & 3D printing of clip-on weights.
- **Curricular tie-ins**: engineering, aerodynamics


### Extension: Engineering Stunt Planes
Challenge learners to design a plane that can perform tricks (turns, loop-the-loops) based on the shape of its wings.
  - Use the vinyl cutter to add crease lines to wings and tail to allow for easy folding.
  - Consider constructing an obstacle course or targets together as a class.



{:toc}

## Materials
- 3mm corrugated cardboard *-or-* 1.5mm or 3mm balsa wood
- Thick (~110lb) cardstock for vinyl cutter
  - Note: construction paper is not advised; it is too fibrous to cut cleanly.
- 3D printer filament (PLA) in a color of your choice
- Laser cutter
- Vinyl cutter
- 3D printer

{:toc}


## Standards Alignment
- Next Generation Science Standards
  - Disciplinary Core Ideas

- Common Core Standards
  -
- ISTE Standards
  -

## Learning Outcomes
### General goals
Learners will be able to…
1. Describe the steps of the iterative engineering design process.
2. Explain the four forces at play in aerodynamics: weight, lift, thrust, drag.
3. Use variables and controls to conduct an experiment.
4. Calculate the average distance of their flight trials.
5. Evaluate the relative success of their designs based on data collected.
6. Communicate their results and make recommendations from their experiments.


### Fabrication goals
Learners will be able to…
1. Use calipers to measure the thickness of stock material.
2. Define parametric design and explain its applications.
3. Laser cut a design they’ve created.
4. Vinyl cut a design they’ve created.
5. Operate the 3D printer to (at a minimum) start a print from a pre-prepared file.


## Facilitator Notes
### 1. Setup & pre-preparation
- Students can work alone or in groups of 2-3.
- Short on time? Pre-cut fuselages and tails and have learners design just their plane’s wings. Nose weights can be 3D printed ahead of time, too!
- Set up a testing zone: vinyl cut and install floor decals to measure distance, or roll out a tape measure for quicker setup and cleanup. Consider also creating targets or using hula hoops to build an obstacle course.


### 2. Adjustments
- This activity has several possible variations, depending on what machines and materials you have available.
  - Balsa wood body, wings, and tail = laser cutter only
  - Balsa wood body + cardstock wings and tail = both laser cutter or laser cutter + vinyl cutter
  - Cardstock body, wings, and tail = vinyl cutter only
  - 3D printed nose weights = optional (you can tape pennies on, instead!)


### 3. Batch processing
- Designs can be cut all at once instead of in separate design/redesign steps: ask each learner or group to design up to three (3) versions of their fuselage, wings, or tail at the beginning of the activity, and cut them together in a single batch. They can then mix and match these parts to test different configurations.

### 4. Design considerations to share with learners
- Consider the center of gravity when designing your plane. How might shifting the wings too far forward or backward affect that center of gravity?


## Discussion questions
- **General**
1. How did the shapes and sizes of the wings, fuselage, and tail affect the overall aerodynamics of your glider? What patterns did you notice?
2. What are the advantages of using parametric design?
3. How can/did iterative testing and redesign help improve the performance of your glider?


- **Digital Fabrication**
1. What are the key differences between using a laser cutter and a vinyl cutter for this project?
2. How does the precision of laser cutting influence the fit and performance of the glider parts?
3. How might using different materials (balsa wood vs. cardstock) for the entire glider affect its weight, durability, and flight characteristics?
4. What similarities and differences did you notice when prepping files for laser cutting versus vinyl cutting?
5. How does the ability to scale your design parametrically benefit the fabrication and iterative testing processes?

- **Physics: Aerodynamics**
1. How did the four forces of aerodynamics (thrust, lift, gravity, drag) interact to influence the flight of your glider?
2. What design features did you include to maximize lift and minimize drag?
3. How did the placement of the wings and tail affect the center of gravity and stability of your glider?
4. What modifications did you (or could you) make to improve the speed, distance, and straightness of your glider’s flight during testing?
5. How can adjusting the weight distribution (using clip-on weights) impact the glider's performance? Why does this occur?
